@@ -8,7 +8,6 @@
 #include <bonobo/bonobo-object.h>
 #include <bonobo/bonobo-wrapper.h>
 #include <bonobo/bonobo-property-bag-client.h>
-#include <bonobo/bonobo-ui-handler.h>
 
 BEGIN_GNOME_DECLS
  
@@ -39,7 +38,7 @@ typedef struct {
 } BonoboControlFrameClass;
 
 
-BonoboControlFrame           *bonobo_control_frame_new                       (Bonobo_UIHandler     uih);
+BonoboControlFrame           *bonobo_control_frame_new                       (Bonobo_Unknown       uih);
 
 GtkWidget                    *bonobo_control_frame_get_widget                (BonoboControlFrame  *frame);
 
@@ -73,14 +72,13 @@ void                          bonobo_control_frame_bind_to_control           (Bo
 
 Bonobo_Control                bonobo_control_frame_get_control               (BonoboControlFrame  *control_frame);
 
-/* The UIHandler */
-Bonobo_UIHandler              bonobo_control_frame_get_ui_handler            (BonoboControlFrame  *control_frame);
+Bonobo_UIContainer            bonobo_control_frame_get_ui_handler            (BonoboControlFrame  *control_frame);
 
 
 /* Object construction stuff */
 BonoboControlFrame           *bonobo_control_frame_construct                 (BonoboControlFrame  *control_frame,
 									      Bonobo_ControlFrame  corba_control_frame,
-									      Bonobo_UIHandler     uih);
+									      Bonobo_UIContainer   uih);
 GtkType                       bonobo_control_frame_get_type                  (void);
 POA_Bonobo_ControlFrame__epv *bonobo_control_frame_get_epv                   (void);
 
