@@ -8,7 +8,9 @@
  * Copyright 1999, 2000 Helix Code, Inc.
  */
 #include <config.h>
+#include <bonobo/Bonobo.h>
 #include <bonobo/bonobo-main.h>
+#include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-property-bag.h>
 #include <bonobo/bonobo-property.h>
 #include <bonobo/bonobo-property-types.h>
@@ -22,13 +24,15 @@ static GtkObjectClass *parent_class = NULL;
  * Internal data structures.
  */
 struct _BonoboPropertyBagPrivate {
-	PortableServer_POA	       poa;
+	PortableServer_POA  poa;
 
-	GHashTable		      *props;
+	GHashTable         *props;
 
-	BonoboPropertySetFn            set_prop;
-	BonoboPropertyGetFn            get_prop;
-	gpointer                       user_data;
+	BonoboPropertySetFn set_prop;
+	BonoboPropertyGetFn get_prop;
+	gpointer            user_data;
+
+	GSList             *listeners;
 };
 
 
@@ -38,7 +42,7 @@ struct _BonoboPropertyBagPrivate {
 
 typedef struct {
 	POA_PortableServer_ServantLocator servant_locator;
-	BonoboPropertyBag *property_bag;
+	BonoboPropertyBag                *property_bag;
 } BonoboPropertyBagServantManager;
 
 /*
@@ -502,6 +506,30 @@ impl_Bonobo_PropertyBag_get_property_names (PortableServer_Servant servant,
 	return name_list;
 }
 
+static void
+impl_Bonobo_PropertyBag_add_listener (PortableServer_Servant        servant,
+				      const CORBA_char             *name,
+				      const Bonobo_PropertyListener listener,
+				      CORBA_Environment            *ev)
+{
+	BonoboPropertyBag *pb = BONOBO_PROPERTY_BAG (
+		bonobo_object_from_servant (servant));
+
+	bonobo_property_bag_add_listener (pb, name, listener, ev);
+}
+						     
+static void
+impl_Bonobo_PropertyBag_remove_listener (PortableServer_Servant        servant,
+				         const CORBA_char             *name,
+					 const Bonobo_PropertyListener listener,
+					 CORBA_Environment            *ev)
+{
+	BonoboPropertyBag *pb = BONOBO_PROPERTY_BAG (
+		bonobo_object_from_servant (servant));
+
+	bonobo_property_bag_remove_listener (pb, name, listener, ev);
+}
+
 
 /*
  * BonoboPropertyBag construction/deconstruction functions. 
@@ -576,10 +604,19 @@ bonobo_property_destroy (BonoboProperty *prop)
 {
 	g_free (prop->name);
 	prop->idx = -1;
-	/*
-	 * If you made up an exotic type code you get to free it.
-	 */
+
 	bonobo_arg_release (prop->default_value);
+
+	/* Unref all listeners */
+	while (prop->listeners) {
+		Bonobo_PropertyListener listener = prop->listeners->data;
+		
+		prop->listeners =
+			g_slist_remove (prop->listeners, listener);
+
+		bonobo_object_release_unref (listener, NULL);
+	}
+
 	g_free (prop->docstring);
 
 	g_free (prop);
@@ -614,6 +651,16 @@ bonobo_property_bag_destroy (GtkObject *object)
 				     NULL);
 	g_hash_table_destroy (pb->priv->props);
 
+	/* Unref all listeners */
+	while (pb->priv->listeners) {
+		Bonobo_PropertyListener listener = pb->priv->listeners->data;
+		
+		pb->priv->listeners =
+			g_slist_remove (pb->priv->listeners, listener);
+
+		bonobo_object_release_unref (listener, NULL);
+	}
+
 	g_free (pb->priv);
 
 	parent_class->destroy (object);
@@ -629,9 +676,11 @@ bonobo_property_bag_get_epv (void)
 
 	epv = g_new0 (POA_Bonobo_PropertyBag__epv, 1);
 
-	epv->get_properties     = impl_Bonobo_PropertyBag_get_properties;
-	epv->get_property       = impl_Bonobo_PropertyBag_get_property;
-	epv->get_property_names = impl_Bonobo_PropertyBag_get_property_names;
+	epv->get_properties		= impl_Bonobo_PropertyBag_get_properties;
+	epv->get_property        	= impl_Bonobo_PropertyBag_get_property;
+	epv->get_property_names  	= impl_Bonobo_PropertyBag_get_property_names;
+	epv->add_change_listener 	= impl_Bonobo_PropertyBag_add_listener;
+	epv->remove_change_listener 	= impl_Bonobo_PropertyBag_remove_listener;
 
 	return epv;
 }
@@ -840,9 +889,69 @@ bonobo_property_bag_add (BonoboPropertyBag  *pb,
 					     pb->priv->user_data);
 }
 
+static void
+notify_listeners (BonoboPropertyBag *pb,
+		  BonoboProperty    *prop,
+		  CORBA_Environment *ev)
+{
+	GSList *l;
+	BonoboArg *arg = bonobo_property_bag_get_value (pb, prop->name);
+	CORBA_Environment *real_ev, tmp_ev;
+
+	if (ev)
+		real_ev = ev;
+	else {
+		CORBA_exception_init (&tmp_ev);
+		real_ev = &tmp_ev;
+	}
+
+	/* Notify the bag listeners. */
+	for (l = pb->priv->listeners; l; l = l->next) {
+		Bonobo_PropertyListener_event ((Bonobo_PropertyListener) l->data, 
+					       prop->name, arg, real_ev);
+
+		if (BONOBO_EX (real_ev))
+			break;
+	}
+
+	if (BONOBO_EX (real_ev)) {
+		if (!ev) {
+			g_warning ("Listener exception '%s' occured.",
+				   bonobo_exception_get_text (real_ev));
+			CORBA_exception_free (&tmp_ev);
+		}
+		return;
+	}
+
+	/* Notify the property listeners. */
+	for (l = prop->listeners; l; l = l->next) {
+		Bonobo_PropertyListener_event ((Bonobo_PropertyListener) l->data, 
+					       prop->name, arg, real_ev);
+
+		if (BONOBO_EX (real_ev))
+			break;
+	}
+
+	if (BONOBO_EX (real_ev)) {
+		if (!ev) {
+			g_warning ("Listener exception '%s' occured.",
+				   bonobo_exception_get_text (real_ev));
+			CORBA_exception_free (&tmp_ev);
+		}
+		return;
+	}
+
+	if (!ev)
+		CORBA_exception_free (&tmp_ev);
+
+	bonobo_arg_release (arg);
+}
+
 void
-bonobo_property_bag_set_value (BonoboPropertyBag *pb, const char *name,
-			       const BonoboArg *value)
+bonobo_property_bag_set_value (BonoboPropertyBag *pb,
+			       const char        *name,
+			       const BonoboArg   *value,
+			       CORBA_Environment *opt_ev)
 {
 	BonoboProperty *prop;
 
@@ -856,9 +965,9 @@ bonobo_property_bag_set_value (BonoboPropertyBag *pb, const char *name,
 	g_return_if_fail (prop->set_prop != NULL);
 	g_return_if_fail (prop->type != value->_type);
 
-	/* FIXME: Emit some sort of CORBA / Bonobo 'changed' signal */
-
 	prop->set_prop (pb, value, prop->idx, prop->user_data);
+
+	notify_listeners (pb, prop, opt_ev);
 }
 
 /**
@@ -1034,3 +1143,128 @@ bonobo_property_bag_get_gtk_type (void)
 
 	return type;
 }
+
+/**
+ * bonobo_property_bag_add_bag_listener:
+ * @pb: the property bag from which to remove
+ * @name: the name of the listener to remove or "" for a global
+ * @listener: the listener to remove
+ * @ev: optional corba environment or NULL
+ * 
+ * Adds a listener for any changes to properties in a bag.
+ */
+void
+bonobo_property_bag_add_listener (BonoboPropertyBag      *pb,
+				  const gchar            *name, 
+				  Bonobo_PropertyListener listener,
+				  CORBA_Environment      *ev)
+{
+	CORBA_Environment *real_ev, tmp_ev;
+
+	g_return_if_fail (pb != NULL);
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (listener != CORBA_OBJECT_NIL);
+
+	if (ev)
+		real_ev = ev;
+	else {
+		CORBA_exception_init (&tmp_ev);
+		real_ev = &tmp_ev;
+	}
+
+	bonobo_property_bag_remove_listener (pb, name, listener, real_ev);
+	if (BONOBO_EX (real_ev))
+		return;
+
+	if (!strcmp (name, ""))
+		pb->priv->listeners =
+			g_slist_prepend (
+				pb->priv->listeners, 
+				bonobo_object_dup_ref (listener, real_ev));
+
+	else if (bonobo_property_bag_has_property (pb, name)) {
+		BonoboProperty *prop = g_hash_table_lookup (pb->priv->props, name);
+
+		if (prop)
+			prop->listeners =
+				g_slist_prepend (
+					prop->listeners,
+					bonobo_object_dup_ref (listener, real_ev));
+	}
+
+	if (BONOBO_EX (real_ev) && !ev)
+		g_warning ("Exception setting listener '%s'",
+			   bonobo_exception_get_text (real_ev));
+
+	if (!ev)
+		CORBA_exception_free (&tmp_ev);
+}
+
+static gint
+listener_cmp (Bonobo_PropertyListener a, Bonobo_PropertyListener b) 
+{
+	return !g_CORBA_Object_equal (a, b);
+}
+
+/**
+ * bonobo_property_bag_remove_listener:
+ * @pb: the property bag from which to remove
+ * @name: the name of the listener to remove or "" for a global
+ * @listener: the listener to remove
+ * @ev: optional corba environment or NULL
+ * 
+ * Removes a listener
+ **/
+void
+bonobo_property_bag_remove_listener (BonoboPropertyBag      *pb,
+				     const gchar            *name, 
+				     Bonobo_PropertyListener listener,
+				     CORBA_Environment      *ev)
+{
+	GSList *node = NULL;
+	CORBA_Environment *real_ev, tmp_ev;
+
+	g_return_if_fail (pb != NULL);
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (listener != CORBA_OBJECT_NIL);
+
+	if (ev)
+		real_ev = ev;
+	else {
+		CORBA_exception_init (&tmp_ev);
+		real_ev = &tmp_ev;
+	}
+
+	if (!strcmp (name, "")) {
+		node = g_slist_find_custom (pb->priv->listeners, listener,
+					   (GCompareFunc) listener_cmp);
+		if (node)
+			pb->priv->listeners = g_slist_remove (
+				pb->priv->listeners, node->data);
+		
+	} else if (bonobo_property_bag_has_property (pb, name)) {
+		BonoboProperty *prop = g_hash_table_lookup (pb->priv->props, name);
+
+		if (prop)
+			node = g_slist_find_custom (prop->listeners, listener,
+						    (GCompareFunc) listener_cmp);
+		if (node)
+			prop->listeners = g_slist_remove (
+				prop->listeners, node->data);
+	}
+
+	if (node) {
+		Bonobo_PropertyListener listener;
+
+		listener = (Bonobo_PropertyListener) node->data; 
+		bonobo_object_release_unref (listener, real_ev);
+	}
+
+	if (BONOBO_EX (real_ev) && !ev)
+		g_warning ("Exception setting listener '%s'",
+			   bonobo_exception_get_text (real_ev));
+
+	if (!ev)
+		CORBA_exception_free (&tmp_ev);
+}
+
