@@ -38,10 +38,11 @@ fs_write (BonoboStream *stream, const Bonobo_Stream_iobuf *buffer,
 	return buffer->_length;
 }
 
-static CORBA_long
-fs_read (BonoboStream *stream, CORBA_long count,
-	 Bonobo_Stream_iobuf ** buffer,
-	 CORBA_Environment *ev)
+static void
+fs_read (BonoboStream         *stream,
+	 CORBA_long            count,
+	 Bonobo_Stream_iobuf **buffer,
+	 CORBA_Environment    *ev)
 {
 	BonoboStreamFS *sfs = BONOBO_STREAM_FS (stream);
 	CORBA_octet *data;
@@ -58,10 +59,13 @@ fs_read (BonoboStream *stream, CORBA_long count,
 	if (v != -1){
 		(*buffer)->_buffer = data;
 		(*buffer)->_length = v;
-	} else
+	} else {
 		CORBA_free (data);
-
-	return v;
+		CORBA_free (*buffer);
+		*buffer = NULL;
+		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+				     ex_Bonobo_Stream_IOError, NULL);
+	}
 }
 
 static CORBA_long
@@ -92,7 +96,8 @@ fs_truncate (BonoboStream *stream,
 	if (ftruncate (sfs->fd, new_size) == 0)
 		return;
 
-	g_warning ("Signal exception");
+	CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
+			     ex_Bonobo_Stream_NoPermission, NULL);
 }
 
 static void
@@ -276,28 +281,6 @@ bonobo_stream_fs_construct (BonoboStreamFS *stream,
 	return BONOBO_STREAM (stream);
 }
 
-static Bonobo_Stream
-create_bonobo_stream_fs (BonoboObject *object)
-{
-	POA_Bonobo_Stream *servant;
-	CORBA_Environment ev;
-
-	servant = (POA_Bonobo_Stream *) g_new0 (BonoboObjectServant, 1);
-	servant->vepv = &bonobo_stream_vepv;
-
-	CORBA_exception_init (&ev);
-
-	POA_Bonobo_Stream__init ((PortableServer_Servant) servant, &ev);
-	if (ev._major != CORBA_NO_EXCEPTION){
-                g_free (servant);
-		CORBA_exception_free (&ev);
-                return CORBA_OBJECT_NIL;
-        }
-
-	CORBA_exception_free (&ev);
-	return (Bonobo_Stream) bonobo_object_activate_servant (object, servant);
-}
-
 static BonoboStream *
 bonobo_stream_create (int fd)
 {
@@ -310,11 +293,11 @@ bonobo_stream_create (int fd)
 	
 	stream_fs->fd = fd;
 	
-	corba_stream = create_bonobo_stream_fs (
+	corba_stream = bonobo_stream_corba_object_create (
 		BONOBO_OBJECT (stream_fs));
 
-	if (corba_stream == CORBA_OBJECT_NIL){
-		gtk_object_destroy (GTK_OBJECT (stream_fs));
+	if (corba_stream == CORBA_OBJECT_NIL) {
+		bonobo_object_unref (BONOBO_OBJECT (stream_fs));
 		return NULL;
 	}
 
@@ -343,20 +326,20 @@ bonobo_stream_fs_open (const CORBA_char *path, Bonobo_Storage_OpenMode mode)
 	
 	v = stat (full, &s);
 
-	if (v == -1){
+	if (v == -1 || S_ISDIR (s.st_mode)) {
 		g_free (full);
 		return NULL;
 	}
 	
-	if (mode == Bonobo_Storage_READ){
+	if (mode == Bonobo_Storage_READ) {
 		fd = open (full, O_RDONLY);
-		if (fd == -1){
+		if (fd == -1) {
 			g_free (full);
 			return NULL;
 		}
-	} else if (mode == Bonobo_Storage_WRITE){
+	} else if (mode == Bonobo_Storage_WRITE) {
 		fd = open (full, O_RDWR);
-		if (fd == -1){
+		if (fd == -1) {
 			g_free (full);
 			return NULL;
 		}
@@ -397,6 +380,3 @@ bonobo_stream_fs_create (const CORBA_char *path)
 
 	return bonobo_stream_create (fd);
 }
-
-
-
