@@ -6,20 +6,13 @@
 
 BEGIN_GNOME_DECLS
 
-struct _BonoboStreamFS;
-typedef struct _BonoboStreamFS BonoboStreamFS;
-
-#ifndef _BONOBO_STORAGE_FS_H_
-struct _BonoboStorageFS;
-typedef struct _BonoboStorageFS BonoboStorageFS;
-#endif
-
 #define BONOBO_STREAM_FS_TYPE        (bonobo_stream_fs_get_type ())
 #define BONOBO_STREAM_FS(o)          (GTK_CHECK_CAST ((o), BONOBO_STREAM_FS_TYPE, BonoboStreamFS))
 #define BONOBO_STREAM_FS_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), BONOBO_STREAM_FS_TYPE, BonoboStreamFSClass))
 #define BONOBO_IS_STREAM_FS(o)       (GTK_CHECK_TYPE ((o), BONOBO_STREAM_FS_TYPE))
 #define BONOBO_IS_STREAM_FS_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), BONOBO_STREAM_FS_TYPE))
 
+typedef struct _BonoboStreamFS BonoboStreamFS;
 typedef struct _BonoboStreamFSPrivate BonoboStreamFSPrivate;
 
 struct _BonoboStreamFS {
