@@ -73,11 +73,13 @@ create_bonobo_view_frame (BonoboObject *object)
 
 static gboolean
 bonobo_view_frame_wrapper_button_press_cb (GtkWidget *wrapper,
-					  GdkEventButton *event,
-					  gpointer data)
+					   GdkEventButton *event,
+					   gpointer data)
 {
 	BonoboViewFrame *view_frame = BONOBO_VIEW_FRAME (data);
 
+	bonobo_object_ref (BONOBO_OBJECT (view_frame));
+
 	/* Check for double click. */
 	if (event->type == GDK_2BUTTON_PRESS)
 		gtk_signal_emit (GTK_OBJECT (view_frame), view_frame_signals [USER_ACTIVATE]);
@@ -87,6 +89,8 @@ bonobo_view_frame_wrapper_button_press_cb (GtkWidget *wrapper,
 		 event->button == 3)
 		gtk_signal_emit (GTK_OBJECT (view_frame), view_frame_signals [USER_CONTEXT]);
 		
+	bonobo_object_unref (BONOBO_OBJECT (view_frame));
+
 	return FALSE;
 } 
 
@@ -97,10 +101,14 @@ bonobo_view_frame_key_press_cb (GtkWidget *wrapper,
 {
 	BonoboViewFrame *view_frame = BONOBO_VIEW_FRAME (data);
 
+	bonobo_object_ref (BONOBO_OBJECT (view_frame));
+
 	/* Hitting enter will activate the embedded component too. */
 	if (event->keyval == GDK_Return)
 		gtk_signal_emit (GTK_OBJECT (view_frame), view_frame_signals [USER_ACTIVATE]);
 
+	bonobo_object_unref (BONOBO_OBJECT (view_frame));
+
 	return FALSE;
 }
 
@@ -118,10 +126,10 @@ bonobo_view_frame_key_press_cb (GtkWidget *wrapper,
  * Bonobo::ViewFrame CORBA service.
  */
 BonoboViewFrame *
-bonobo_view_frame_construct (BonoboViewFrame  *view_frame,
-			     Bonobo_ViewFrame  corba_view_frame,
-			     BonoboClientSite *client_site,
-			     Bonobo_UIHandler  uih)
+bonobo_view_frame_construct (BonoboViewFrame   *view_frame,
+			     Bonobo_ViewFrame   corba_view_frame,
+			     BonoboClientSite  *client_site,
+			     Bonobo_UIContainer uih)
 {
 	GtkWidget *wrapper;
 
@@ -167,14 +175,14 @@ bonobo_view_frame_construct (BonoboViewFrame  *view_frame,
 /**
  * bonobo_view_frame_new:
  * @client_site: the client site to which the newly-created ViewFrame will belong.
- * @uih: A CORBA object for the container's UIHandler server. 
+ * @uih: A CORBA object for the container's UIContainer server. 
  *
  * Returns: BonoboViewFrame object that implements the
  * Bonobo::ViewFrame CORBA service.
  */
 BonoboViewFrame *
-bonobo_view_frame_new (BonoboClientSite *client_site,
-		       Bonobo_UIHandler  uih)
+bonobo_view_frame_new (BonoboClientSite  *client_site,
+		       Bonobo_UIContainer uih)
 {
 	Bonobo_ViewFrame corba_view_frame;
 	BonoboViewFrame *view_frame;
@@ -378,10 +386,10 @@ bonobo_view_frame_set_covered (BonoboViewFrame *view_frame, gboolean covered)
  * bonobo_view_frame_get_ui_handler:
  * @view_frame: A BonoboViewFrame object.
  *
- * Returns: The BonoboUIHandler associated with this ViewFrame.  See
+ * Returns: The BonoboUIContainer associated with this ViewFrame.  See
  * also bonobo_view_frame_set_ui_handler().
  */
-Bonobo_UIHandler
+Bonobo_UIContainer
 bonobo_view_frame_get_ui_handler (BonoboViewFrame *view_frame)
 {
 	g_return_val_if_fail (view_frame != NULL, NULL);
@@ -498,6 +506,7 @@ bonobo_view_frame_set_zoom_factor (BonoboViewFrame *view_frame, double zoom)
 	CORBA_exception_free (&ev);
 }
 
+#ifdef STALE_NOT_USED
 static void
 bonobo_view_frame_verb_selected_cb (BonoboUIHandler *uih, void *user_data,
 				   const char *path)
@@ -524,6 +533,7 @@ bonobo_view_frame_verb_selected_cb (BonoboUIHandler *uih, void *user_data,
 	gtk_object_set_data (GTK_OBJECT (view_frame), "view_frame_executed_verb_name",
 			     g_strdup (verb_name));
 }
+#endif
 
 /**
  * bonobo_view_frame_popup_verbs:
@@ -543,6 +553,7 @@ bonobo_view_frame_verb_selected_cb (BonoboUIHandler *uih, void *user_data,
 char *
 bonobo_view_frame_popup_verbs (BonoboViewFrame *view_frame)
 {
+#ifdef STALE_NOT_USED
 	BonoboUIHandler *popup;
 	GList *verbs, *l;
 	char *verb;
@@ -596,6 +607,9 @@ bonobo_view_frame_popup_verbs (BonoboViewFrame *view_frame)
 	gtk_object_remove_data (GTK_OBJECT (view_frame), "view_frame_executed_verb_name");
 
 	return verb;
+#else
+	return NULL;
+#endif /* STALE_NOT_USED */
 }
 
 /**
