@@ -45,9 +45,13 @@ impl_Bonobo_View_do_verb (PortableServer_Servant servant,
 			 const CORBA_char      *verb_name,
 			 CORBA_Environment     *ev)
 {
+#ifdef STALE_NOT_USED
 	BonoboView *view = BONOBO_VIEW (bonobo_object_from_servant (servant));
 
 	bonobo_view_execute_verb (view, verb_name);
+#else
+	g_warning ("Verbs have jumped interface");
+#endif
 }
 
 static void
@@ -405,7 +409,7 @@ bonobo_view_get_ui_handler (BonoboView *view)
  *
  * Returns: The Bonobo_UIHandler CORBA server for the remote BonoboViewFrame.
  */
-Bonobo_UIHandler
+Bonobo_UIContainer
 bonobo_view_get_remote_ui_handler (BonoboView *view)
 {
 	g_return_val_if_fail (view != NULL, CORBA_OBJECT_NIL);
@@ -482,6 +486,7 @@ bonobo_view_unregister_verb (BonoboView *view, const char *verb_name)
 	g_free (original_key);
 }
 
+#ifdef STALE_NOT_USED
 /**
  * bonobo_view_execute_verb:
  * @view: A BonoboView object.
@@ -544,6 +549,7 @@ bonobo_view_verb_selected_cb (BonoboUIHandler *uih, void *user_data,
 			     g_strdup (verb_name));
 	
 }
+#endif /* STALE_NOT_USED */
 
 /**
  * bonobo_view_popup_verbs:
@@ -557,6 +563,7 @@ bonobo_view_verb_selected_cb (BonoboUIHandler *uih, void *user_data,
 char *
 bonobo_view_popup_verbs (BonoboView *view)
 {
+#ifdef STALE_NOT_USED
 	BonoboUIHandler *popup;
 	const GList *verbs;
 	const GList *l;
@@ -610,4 +617,7 @@ bonobo_view_popup_verbs (BonoboView *view)
 	gtk_object_remove_data (GTK_OBJECT (view), "view_executed_verb_name");
 
 	return verb;
+#else
+	return NULL;
+#endif /* STALE_NOT_USED */
 }
