@@ -17,13 +17,15 @@ extern "C" {
 
 #include <bonobo/bonobo-object.h>
 #include <bonobo/bonobo-moniker.h>
+#include <bonobo/bonobo-exception.h>
 
-#include <bonobo/bonobo-container.h>
+#include <bonobo/bonobo-item-container.h>
 #include <bonobo/bonobo-object-client.h>
 #include <bonobo/bonobo-moniker-util.h>
 #include <bonobo/bonobo-client-site.h>
 
 #include <bonobo/bonobo-property-bag.h>
+#include <bonobo/bonobo-property-listener.h>
 #include <bonobo/bonobo-property-bag-client.h>
 
 #include <bonobo/bonobo-control.h>
@@ -46,7 +48,14 @@ extern "C" {
 #include <bonobo/bonobo-persist-file.h>
 #include <bonobo/bonobo-persist-stream.h>
 
-#include <bonobo/bonobo-ui-handler.h>
+/* Deprecated */
+#include <bonobo/bonobo-ui-compat.h>
+
+#include <bonobo/bonobo-ui-xml.h>
+#include <bonobo/bonobo-ui-util.h>
+#include <bonobo/bonobo-ui-component.h>
+#include <bonobo/bonobo-ui-container.h>
+#include <bonobo/bonobo-win.h>
 
 #include <bonobo/bonobo-object-io.h>
 
