@@ -260,7 +260,7 @@ static void
 view_create_menus (view_data_t *view_data)
 {
 	BonoboUIHandler *uih;
-	Bonobo_UIHandler remote_uih;
+	Bonobo_UIContainer remote_uih;
 	BonoboView *view = view_data->view;
 
 	/*
