@@ -88,6 +88,10 @@ typedef struct {
 
 	gboolean	  active;
 
+	/* UI stuff. */
+	BonoboUIComponent *uih;
+	Bonobo_UIContainer remote_uih;
+
 	/* Internal widgets. */
 	GtkWidget	 *sw;
 	GtkWidget	 *table;
@@ -103,6 +107,8 @@ destroy_view (view_data_t *view_data)
 		g_list_remove (view_data->bonobo_object_data->views,
 			       view_data);
 
+	destroy_view_menus (view_data);
+
 	g_free (view_data);
 } /* destroy_view */
 
@@ -409,15 +415,10 @@ text_deleted_cb (GtkText *text,
 
 
 static void
-clear_text_cb (BonoboUIHandler *uih, void *data,
-	       const char *path)
+verb_ClearText_cb (BonoboUIComponent *uih, view_data_t *view_data, const char *cname)
 {
-	view_data_t *view_data = (view_data_t *) data;
-
-
 	blank_all_views (view_data->bonobo_object_data);
 	free_text (view_data->bonobo_object_data);
-
 } /* clear_text_cb */
 
 
@@ -430,30 +431,33 @@ clear_text_cb (BonoboUIHandler *uih, void *data,
 static void
 create_view_menus (view_data_t *view_data)
 {
-	Bonobo_UIHandler remote_uih;
-	BonoboUIHandler *uih;
-	char label[256];
+	BonoboUINode *parent, *node;
+	Bonobo_UIContainer remote_uih;
+	char *label;
 
 	/*
 	 * Register with the UI Handler and add some menu entries.
 	 */
-	uih = bonobo_view_get_ui_handler (view_data->view);
+	view_data->uih = bonobo_ui_component_new ("text-plain");
 	remote_uih = bonobo_view_get_remote_ui_handler (view_data->view);
 	if (remote_uih == CORBA_OBJECT_NIL)
 		return;
 
-	bonobo_ui_handler_set_container (uih, remote_uih);
-		
-	bonobo_ui_handler_menu_new_separator (uih, "/text\\/plain/separator1", -1);
+	view_data->remote_uih = bonobo_object_dup_ref (remote_uih, NULL);
 
-	snprintf (label, sizeof (label), "Clear Text (containee-added item for view %p)", view_data);
-	bonobo_ui_handler_menu_new_item (uih, "/text\\/plain/Clear text", 
-					label, NULL, -1, BONOBO_UI_HANDLER_PIXMAP_XPM_DATA,
-					bolt_xpm, 0, 0, clear_text_cb, view_data);
+	label = g_strdup_printf ("_Clear Text (containee-added item for view %p)", view_data);
 
-	bonobo_ui_handler_menu_new_item (uih, "/text\\/plain/Clear text", 
-					label, NULL, -1, BONOBO_UI_HANDLER_PIXMAP_XPM_DATA,
-					bolt_xpm, 0, 0, clear_text_cb, view_data);
+	parent = bonobo_ui_util_new_menu (TRUE, "text-plain", "_text-plain",
+					  "text-plain component", NULL);
+
+	node = bonobo_ui_util_new_menu (FALSE, "ClearText", label, label, "ClearText");
+	bonobo_ui_util_xml_set_pix_xpm (node, (const char **) bolt_xpm);
+	bonobo_ui_node_add_child (parent, node);
+
+	bonobo_ui_component_add_verb (view_data->uih, "ClearText", (BonoboUIVerbFn) verb_ClearText_cb,
+				      view_data);
+
+	bonobo_ui_component_set_tree (view_data->uih, view_data->remote_uih, "/menu", parent, NULL);
 
 	#if 0
 	bonobo_ui_handler_create_toolbar (uih, "Common");
@@ -467,12 +471,17 @@ create_view_menus (view_data_t *view_data)
 static void
 destroy_view_menus (view_data_t *view_data)
 {
-	BonoboView *view = view_data->view;
-	BonoboUIHandler *uih;
+	if ((view_data->uih == NULL) || (view_data->remote_uih == CORBA_OBJECT_NIL))
+		return;
 
-	uih = bonobo_view_get_ui_handler (view);
+	bonobo_ui_component_rm (view_data->uih, view_data->remote_uih,
+				"/menu/text-plain/", NULL);
 
-	bonobo_ui_handler_unset_container (uih);
+	bonobo_object_release_unref (view_data->remote_uih, NULL);
+	bonobo_object_unref (BONOBO_OBJECT (view_data->uih));
+
+	view_data->remote_uih = CORBA_OBJECT_NIL;
+	view_data->uih = NULL;
 }
 
 static void
@@ -845,8 +854,8 @@ embeddable_factory (BonoboEmbeddableFactory *this,
 	running_objects++;
 
 	gtk_signal_connect_after (GTK_OBJECT (bonobo_object), "destroy",
-			    GTK_SIGNAL_FUNC (bonobo_object_destroy_cb),
-			    bonobo_object_data);
+				  GTK_SIGNAL_FUNC (bonobo_object_destroy_cb),
+				  bonobo_object_data);
 
 	gtk_signal_connect (GTK_OBJECT (bonobo_object), "system_exception",
 			    GTK_SIGNAL_FUNC (embeddable_system_exception_cb),
