@@ -13,14 +13,14 @@ BEGIN_GNOME_DECLS
 typedef struct _BonoboMonikerItem        BonoboMonikerItem;
 
 struct _BonoboMonikerItem {
-	BonoboMoniker stream;
+	BonoboMoniker parent;
 };
 
 typedef struct {
 	BonoboMonikerClass parent_class;
 } BonoboMonikerItemClass;
 
-GtkType        bonobo_moniker_item_get_type  (void);
+GtkType bonobo_moniker_item_get_type (void);
 	
 END_GNOME_DECLS
 
