@@ -1,4 +1,4 @@
-/* $Id: component.c,v 1.10 2000/08/11 19:35:05 mmeeks Exp $ */
+/* $Id: component.c,v 1.12 2000/09/23 14:20:00 mmeeks Exp $ */
 
 #include "component.h"
 #include "embeddable-io.h"
@@ -142,9 +142,8 @@ sample_client_site_add_frame (SampleClientSite *site)
 	 */
 	view_frame = bonobo_client_site_new_view (
 		BONOBO_CLIENT_SITE (site),
-		bonobo_object_corba_objref (BONOBO_OBJECT (
-			site->app->ui_handler)));
-
+		bonobo_ui_compat_get_container (site->app->ui_handler));
+	
 	/*
 	 * Embed the view frame into the application.
 	 */
@@ -427,18 +426,18 @@ sample_client_site_get_widget (SampleClientSite *site)
 }
 
 SampleClientSite *
-sample_client_site_new (BonoboContainer *container,
-			SampleApp       *app,
-			BonoboObjectClient *embeddable,
-			const char         *embeddable_id)
+sample_client_site_new (BonoboItemContainer *container,
+			SampleApp           *app,
+			BonoboObjectClient  *embeddable,
+			const char          *embeddable_id)
 {
 	SampleClientSite *site;
 	Bonobo_ClientSite corba_client_site;
 
 	g_return_val_if_fail (app != NULL, NULL);
 	g_return_val_if_fail (embeddable_id != NULL, NULL);
-	g_return_val_if_fail (BONOBO_IS_CONTAINER (container), NULL);
 	g_return_val_if_fail (BONOBO_IS_OBJECT_CLIENT (embeddable), NULL);
+	g_return_val_if_fail (BONOBO_IS_ITEM_CONTAINER (container), NULL);
 	
 	site = gtk_type_new (sample_client_site_get_type ());
 	corba_client_site = bonobo_client_site_corba_object_create
@@ -456,8 +455,7 @@ sample_client_site_new (BonoboContainer *container,
 		bonobo_client_site_bind_embeddable (BONOBO_CLIENT_SITE (site),
 						    embeddable);
 		bonobo_object_unref (BONOBO_OBJECT (embeddable));
-		bonobo_container_add (container,
-				      BONOBO_OBJECT (site));
+		bonobo_item_container_add (container, BONOBO_OBJECT (site));
 
 		site->app = app;
 		g_free (site->obj_id);
