@@ -160,6 +160,8 @@ view_set_color (view_data_t *view_data, char *color)
 	GdkColormap *colormap;
 	GdkColor gdk_color;
 
+	fprintf (stderr, "Set color to '%s'\n", color);
+
 	colormap = gtk_widget_get_colormap (view_data->drawing_area);
 
 	gdk_color_parse (color, &gdk_color);
@@ -177,6 +179,8 @@ view_color_select_cb (BonoboUIHandler *uih, view_data_t *view_data, char *path)
 		view_set_color (view_data, "white");
 	else if (strstr (path, "Green") != NULL)
 		view_set_color (view_data, "green");
+	else
+		g_error ("set to unknown color");
 }
 
 /*
@@ -186,7 +190,7 @@ view_color_select_cb (BonoboUIHandler *uih, view_data_t *view_data, char *path)
 static void
 view_create_menus (view_data_t *view_data)
 {
-	Bonobo_UIHandler  remote_uih;
+	Bonobo_UIContainer remote_uih;
 	BonoboView       *view = view_data->view;
 	BonoboUIHandler  *uih;
 	int               i;
@@ -217,6 +221,8 @@ view_create_menus (view_data_t *view_data)
 	/*
 	 * Create our menu entries.
 	 */
+	bonobo_ui_handler_create_menubar (uih);
+
 	bonobo_ui_handler_menu_new_subtree (uih, "/Colors",
 					   N_("Select drawing color..."),
 					   N_("Set the current drawing color"),
